@@ -230,7 +230,7 @@
   
   [adj connectObjMethod:"value_changed" :self :@selector(zoom_changed:)];
 
-  label = [[[Gtk_Label new] initWithLabel:"Click on the curve to move it"] show];
+  label = [[[Gtk_Label new] initWithLabel:_("Click on the curve to move it")] show];
   [vbox pack_start:label doExpand:TRUE doFill:TRUE doPadding:5];
  
 
@@ -356,7 +356,7 @@
 	[[ Gnome_Canvas_Text alloc] initWithGroup: group
 				    : "x", 150.0,
 				    "y", 140.0,
-				    "text", "This is a simple Koch Curve",
+				    "text", _("This is a simple Koch Curve"),
 				    NULL];
 
 
