@@ -23,12 +23,6 @@
   return self;
 }
 
-- set_modal
-{
-  gtk_window_set_modal(gnomedialog, TRUE);
-  return self;
-}
-
 - set_default:(gint) button;
 {
   gnome_dialog_set_default(gnomedialog, button);
