@@ -24,7 +24,7 @@
 
 - set_accel_widget:(id) accel_widget
 {
-  gtk_accel_label_set_accel_widget(gtkaccellabel, accel_widget);
+  gtk_accel_label_set_accel_widget(gtkaccellabel, ((Gtk_Widget *)accel_widget)->gtkwidget);
   return self;
 }
 
