@@ -14,9 +14,6 @@
 - set_border_width:(gint) width;
 - add:(id) widget;
 - remove:(id) widget;
-- block_resize;
-- unblock_resize;
-- (gint)need_resize;
 - foreach    : callbackFunction:(GtkCallback) acallback
 callbackData:(gpointer) callback_data;
 - foreach_method:(SEL) method; /* this method should take no explicit arguments */
