@@ -3,6 +3,7 @@
 
 #include <obgtk/obgtkWidget.h>
 #include <gtk/gtkeditable.h>
+#include <gtk/gtkfeatures.h>
 
 @interface Gtk_Editable : Gtk_Widget
 {
@@ -18,9 +19,9 @@
 	     :(gint) end_pos;
 - (gchar *) get_chars:(gint) start_pos
 		     :(gint) end_pos;
-- cut_clipboard:(guint32) time;
-- copy_clipboard:(guint32) time;
-- paste_clipboard:(guint32) time;
+- cut_clipboard;
+- copy_clipboard;
+- paste_clipboard;
 - claim_selection:(gboolean) claim :(guint32) time;
 - delete_selection;
 - changed;
