@@ -34,7 +34,6 @@
   return gtk_editable_get_chars(gtkeditable, start_pos, end_pos);
 }
 
-#if (GTK_MAJOR_VERSION==1) && (GTK_MINOR_VERSION==1)
 - cut_clipboard
 {
   gtk_editable_cut_clipboard(gtkeditable);
@@ -52,25 +51,6 @@
   gtk_editable_paste_clipboard(gtkeditable);
   return self;
 }
-#else
-- cut_clipboard:(guint32) time
-{
-  gtk_editable_cut_clipboard(gtkeditable, time);
-  return self;
-}
-
-- copy_clipboard:(guint32) time
-{
-  gtk_editable_copy_clipboard(gtkeditable, time);
-  return self;
-}
-
-- paste_clipboard:(guint32) time
-{
-  gtk_editable_paste_clipboard(gtkeditable, time);
-  return self;
-}
-#endif
 
 - claim_selection:(gboolean) claim :(guint32) time
 {
