@@ -6,7 +6,7 @@
 
 /* #define DEBUG 1 */
 
-guint obgtk_objc_id_key = 0;
+GQuark obgtk_objc_id_key = 0;
 #ifdef DEBUG
 static int foobar = 0;
 #endif
@@ -14,7 +14,7 @@ static int foobar = 0;
 guint OBJC_ID(void)
 {
   if(!obgtk_objc_id_key)
-    obgtk_objc_id_key = gtk_object_data_force_id("objc_id");
+    obgtk_objc_id_key = g_quark_from_static_string("objc_id");
   return obgtk_objc_id_key;
 }
 
@@ -175,12 +175,13 @@ obgtk_callback_relay(GtkObject *object,
   mydata = g_new(struct _ObgtkRelayInfo, 1);
   mydata->object = self;
   mydata->method = @selector(destroyGtkObject);
-  destroy_handler_id = gtk_signal_connect_interp(gtkobject,
+  destroy_handler_id = gtk_signal_connect_full(gtkobject,
 				 "destroy",
+				 NULL,
 				 (GtkCallbackMarshal)obgtk_signal_relay,
 				 mydata,
 				 g_free,
-				 GTK_RUN_LAST);
+				 FALSE, GTK_RUN_LAST);
   return self;
 }
 
@@ -264,12 +265,12 @@ obgtk_callback_relay(GtkObject *object,
 					--these must be pointers-- */
       mydata->method = sel_get_uid(foo->str);
     }
-  rv = gtk_signal_connect_interp(gtkobject,
-				 signal_name,
+  rv = gtk_signal_connect_full(gtkobject,
+				 signal_name, NULL,
 				 (GtkCallbackMarshal)obgtk_signal_relay,
 				 mydata,
 				 g_free,
-				 GTK_RUN_LAST);
+				 FALSE, GTK_RUN_LAST);
   if(ret_handler_id)
     *ret_handler_id = rv;
   g_free(siginfo);
