@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkPixmap.h"
 
 @implementation Gtk_Pixmap
 
