@@ -20,11 +20,6 @@
      :(gint) desty
      :(gint) width
      :(gint) height;
-- put_row:(guchar *) src
-	 :(guchar *) dest
-	 :(gint) x
-	 :(gint) y
-	 :(gint) w;
 - draw_row:(guchar *) data
 	  :(gint) x
 	  :(gint) y
