@@ -33,16 +33,6 @@
   return self;
 }
 
-- put_row:(guchar *) src
-	 :(guchar *) dest
-	 :(gint) x
-	 :(gint) y
-	 :(gint) w
-{
-  gtk_preview_put_row(gtkpreview, src, dest, x, y, w);
-  return self;
-}
-
 - draw_row:(guchar *) data
 	  :(gint) x
 	  :(gint) y
