@@ -10,10 +10,9 @@
   GtkToggleButton *gtktogglebutton;
 }
 - castGtkToggleButton:(GtkToggleButton *)castitem;
-- init;
 - initWithLabel:(gchar *) label;
 - set_mode:(gint) draw_indicator;
-- set_state:(gint) state;
+- set_active:(gboolean) is_active;
 - toggled;
 @end
 
