@@ -25,9 +25,9 @@
   return self;
 }
 
-- set_state:(gint) state
+- set_active:(gboolean) is_active
 {
-  gtk_toggle_button_set_state(gtktogglebutton, state);
+  gtk_toggle_button_set_active(gtktogglebutton, is_active);
   return self;
 }
 
