@@ -37,15 +37,28 @@
   return self;
 }
 
-- set_policy:
-allowShrink:(gint) allow_shrink
-allowGrow:(gint) allow_grow
-autoShrink:(gint) auto_shrink
+- set_policy:(gint) allow_shrink
+   allowGrow:(gint) allow_grow
+  autoShrink:(gint) auto_shrink
 {
   gtk_window_set_policy(gtkwindow, allow_shrink, allow_grow, auto_shrink);
   return self;
 }
 
+#ifdef GTK_HAVE_FEATURES_1_1_0
+- add_accel_group:(Gtk_AccelGroup *) group
+{
+  gtk_window_add_accel_group(gtkwindow, group->gtkaccelgroup);
+  return self;
+}
+
+- remove_accel_group:(Gtk_AccelGroup *) group
+{
+  gtk_window_remove_accel_group(gtkwindow,
+				      group->gtkaccelgroup);
+  return self;
+}
+#else
 - add_accelerator_table:(Gtk_AcceleratorTable *) table
 {
   gtk_window_add_accelerator_table(gtkwindow, table->gtkacceleratortable);
@@ -58,10 +71,11 @@ autoShrink:(gint) auto_shrink
 				      table->gtkacceleratortable);
   return self;
 }
+#endif
 
-- position:(GtkWindowPosition) position
+- set_position:(GtkWindowPosition) position
 {
-  gtk_window_position(gtkwindow, position);
+  gtk_window_set_position(gtkwindow, position);
   return self;
 }
 
